@@ -1,15 +1,7 @@
-#!/usr/bin/perl
-
 package App::Licensecheck;
 
-use v5.14;
 use utf8;
 use strictures 2;
-use warnings qw(FATAL utf8);
-use charnames qw(:full :short);
-no warnings "nonchar";
-no warnings "surrogate";
-no warnings "non_unicode";
 use autodie;
 
 use version;
@@ -28,11 +20,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.8
+Version v3.0.9
 
 =cut
 
-our $VERSION = version->declare("v3.0.8");
+our $VERSION = version->declare("v3.0.9");
 
 =head1 SYNOPSIS
 
